@@ -1,7 +1,7 @@
 package Evo::Comp::Out;
 use Evo '-Export *';
 use Evo::Lib 'monkey_patch';
-use Evo '::Gen::HUF GEN; ::Role ROLE_EXPORTER';
+use Evo '::Gen::HUF GEN; -Role ROLE_EXPORTER';
 use Evo '::Meta';
 
 my $META = Evo::Comp::Meta::new(gen => GEN, rex => ROLE_EXPORTER);
@@ -12,11 +12,24 @@ export_gen has => sub($class) {
   sub { $META->install_attr($class, @_); };
 };
 
-
 export_gen with => sub($class) {
   sub { $META->install_roles($class, @_); };
 };
 
+export_gen overrides => sub($class) {
+  sub { $META->mark_overriden($class, @_); };
+};
+
+
+export_anon MODIFY_CODE_ATTRIBUTES => sub($class, $code, @attrs) {
+  my @bad = grep { $_ ne 'Override' } @attrs;
+  return @bad if @bad;
+
+  Evo::Util::find_subnames($class, $code);
+  $META->mark_overriden($class, Evo::Util::find_subnames($class, $code));
+  return;
+};
+
 
 1;
 
@@ -32,7 +45,7 @@ Evo::Comp::Out
 
 =head1 VERSION
 
-version 0.0186
+version 0.0199
 
 =head1 DESCRIPTION
 
