@@ -1,5 +1,5 @@
 package Evo::Loop::Role::Zone;
-use Evo '-Comp::Role *';
+use Evo '-Role *';
 use Evo::Lib '*';
 use Carp 'croak';
 
@@ -43,7 +43,7 @@ Evo::Loop::Role::Zone
 
 =head1 VERSION
 
-version 0.0186
+version 0.0199
 
 =head1 AUTHOR
 
