@@ -1,11 +1,11 @@
 package Evo::Net::Socket;
 use Evo '-Comp::Out *; Symbol gensym';
 
-with ':Role';
+with ':Role', '-Io::Role';
 
 our @CARP_NOT = qw(Evo::Net::Server::Role);
 
-sub new() { my $s = init(gensym) }
+sub new() { init(gensym) }
 
 1;
 
@@ -21,7 +21,7 @@ Evo::Net::Socket
 
 =head1 VERSION
 
-version 0.0186
+version 0.0199
 
 =head1 SYNOPSYS
 
@@ -38,6 +38,19 @@ Opens socket just like C<socket>. If already opened, dies
 
   my $sock = Evo::Net::Socket::new()->socket_open(AF_INET6, SOCK_STREAM, IPPROTO_TCP);
 
+=head2 socket_local
+
+=head2 socket_remote
+
+  my ($ip, $port) = $sock->socket_remote;
+  ($ip, $port) = $sock->socket_local;
+
+More frienly results than C<getpeername> and C<getsockname> 
+
+=head2 socket_accept
+
+Instead of saddr return a new socket and initiate with the C<init> method of the derived class
+
 =head1 Info
 
   say $sock->socket_reuseaddr(1)->socket_reuseaddr;    # 1
@@ -64,7 +77,11 @@ Opens socket just like C<socket>. If already opened, dies
 
 =item * socket_nodelay
 
-=item * socket_nb
+=item * socket_rcvbuf
+
+=item * socket_sndbuf
+
+=item * non_blocking
 
 =back
 
